@@ -1,4 +1,4 @@
-coxsplsDR.formula <- function(Xplan,time,time2,event,type,origin,typeres="deviance", collapse, weighted, scaleX=TRUE, scaleY=TRUE, ncomp=min(7,ncol(Xplan)), validation = "CV", plot=FALSE, allres=FALSE,dataXplan=NULL,subset,weights,model_frame=FALSE, eta, trace=FALSE,...) {
+coxsplsDR.formula <- function(Xplan,time,time2,event,type,origin,typeres="deviance", collapse, weighted, scaleX=TRUE, scaleY=TRUE, ncomp=min(7,ncol(Xplan)), modepls = "regression", plot=FALSE, allres=FALSE,dataXplan=NULL,subset,weights,model_frame=FALSE, eta, trace=FALSE,...) {
 
 if (missing(dataXplan)) 
 dataXplan <- environment(Xplan)
@@ -28,5 +28,5 @@ if (!is.null(weights) && !is.numeric(weights))
 if (!is.null(weights) && any(weights < 0)) 
     stop("negative weights not allowed")
 
-NextMethod("coxplsDR2")
+NextMethod("coxsplsDR")
 }
