@@ -4,7 +4,7 @@ options(warn = 1)
 options(pager = "console")
 library('plsRcox')
 
-assign(".oldSearch", search(), pos = 'CheckExEnv')
+base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
 cleanEx()
 nameEx("DR_coxph")
 ### * DR_coxph
@@ -43,10 +43,56 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
+
+
+
+cleanEx()
+nameEx("coxDKpls2DR")
+### * coxDKpls2DR
+
+flush(stderr()); flush(stdout())
+
+### Name: coxDKpls2DR
+### Title: Fitting a Direct Kernel PLS model on the (Deviance) Residuals
+### Aliases: coxDKpls2DR coxDKpls2DR.default coxDKpls2DR.formula
+### Keywords: models regression
+
+### ** Examples
+
+data(micro.censure)
 data(Xmicro.censure_compl_imp)
-X_train_micro <- Xmicro.censure_compl_imp[1:80,]
-X_test_micro <- Xmicro.censure_compl_imp[81:117,]
-rm(X_train_micro,X_test_micro)
+
+X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
+X_train_micro_df <- data.frame(X_train_micro)
+Y_train_micro <- micro.censure$survyear[1:80]
+C_train_micro <- micro.censure$DC[1:80]
+
+(cox_DKpls2DR_fit=coxDKpls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
+
+#Fixing sigma to compare with pls2DR on Gram matrix; should be identical
+(cox_DKpls2DR_fit=coxDKpls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",hyperkernel=list(sigma=0.01292786)))
+
+library(kernlab)
+X_train_micro_kern <- kernelMatrix(rbfdot(sigma=0.01292786),scale(X_train_micro))
+(cox_DKpls2DR_fit2=coxpls2DR(~X_train_micro_kern,Y_train_micro,C_train_micro,ncomp=6,validation="CV",scaleX=FALSE))
+detach(package:kernlab)
+
+(cox_DKpls2DR_fit=coxDKpls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",kernel="laplacedot",hyperkernel=list(sigma=0.01292786)))
+
+library(kernlab)
+X_train_micro_kern <- kernelMatrix(laplacedot(sigma=0.01292786),scale(X_train_micro))
+(cox_DKpls2DR_fit2=coxpls2DR(~X_train_micro_kern,Y_train_micro,C_train_micro,ncomp=6,validation="CV",scaleX=FALSE))
+detach(package:kernlab)
+
+(cox_DKpls2DR_fit=coxDKpls2DR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
+(cox_DKpls2DR_fit=coxDKpls2DR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",dataXplan=X_train_micro_df))
+
+(cox_DKpls2DR_fit=coxDKpls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE))
+(cox_DKpls2DR_fit=coxDKpls2DR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE))
+(cox_DKpls2DR_fit=coxDKpls2DR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE,dataXplan=X_train_micro_df))
+
+
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_DKpls2DR_fit)
 
 
 
@@ -71,35 +117,68 @@ X_train_micro_df <- data.frame(X_train_micro)
 Y_train_micro <- micro.censure$survyear[1:80]
 C_train_micro <- micro.censure$DC[1:80]
 
-(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
+(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
 
 #Fixing sigma to compare with plsDR on Gram matrix; should be identical
-(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",hyperkernel=list(sigma=0.01292786)))
+(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,hyperkernel=list(sigma=0.01292786)))
 
 library(kernlab)
 X_train_micro_kern <- kernelMatrix(rbfdot(sigma=0.01292786),scale(X_train_micro))
-(cox_DKplsDR_fit2=coxplsDR(~X_train_micro_kern,Y_train_micro,C_train_micro,ncomp=6,validation="CV",scaleX=FALSE))
+(cox_DKplsDR_fit2=coxplsDR(~X_train_micro_kern,Y_train_micro,C_train_micro,ncomp=6,scaleX=FALSE))
 detach(package:kernlab)
 
-(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",kernel="laplacedot",hyperkernel=list(sigma=0.01292786)))
+(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,kernel="laplacedot",hyperkernel=list(sigma=0.01292786)))
 
 library(kernlab)
 X_train_micro_kern <- kernelMatrix(laplacedot(sigma=0.01292786),scale(X_train_micro))
-(cox_DKplsDR_fit2=coxplsDR(~X_train_micro_kern,Y_train_micro,C_train_micro,ncomp=6,validation="CV",scaleX=FALSE))
+(cox_DKplsDR_fit2=coxplsDR(~X_train_micro_kern,Y_train_micro,C_train_micro,ncomp=6,scaleX=FALSE))
 detach(package:kernlab)
 
-(cox_DKplsDR_fit=coxDKplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
-(cox_DKplsDR_fit=coxDKplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",dataXplan=X_train_micro_df))
+(cox_DKplsDR_fit=coxDKplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
+(cox_DKplsDR_fit=coxDKplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df))
 
-(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE))
-(cox_DKplsDR_fit=coxDKplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE))
-(cox_DKplsDR_fit=coxDKplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE,dataXplan=X_train_micro_df))
+(cox_DKplsDR_fit=coxDKplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,allres=TRUE))
+(cox_DKplsDR_fit=coxDKplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,allres=TRUE))
+(cox_DKplsDR_fit=coxDKplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,allres=TRUE,dataXplan=X_train_micro_df))
 
 
 rm(X_train_micro,Y_train_micro,C_train_micro,cox_DKplsDR_fit)
 
 
 
+cleanEx()
+nameEx("coxDKspls2DR")
+### * coxDKspls2DR
+
+flush(stderr()); flush(stdout())
+
+### Name: coxDKspls2DR
+### Title: Fitting a Direct Kernel sPLSR model on the (Deviance) Residuals
+### Aliases: coxDKspls2DR coxDKspls2DR.default coxDKspls2DR.formula
+### Keywords: models regression
+
+### ** Examples
+
+data(micro.censure)
+data(Xmicro.censure_compl_imp)
+
+X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
+X_train_micro_df <- data.frame(X_train_micro)
+Y_train_micro <- micro.censure$survyear[1:80]
+C_train_micro <- micro.censure$DC[1:80]
+
+(cox_DKspls2DR_fit=coxDKspls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",eta=.5))
+(cox_DKspls2DR_fit=coxDKspls2DR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",eta=.5))
+(cox_DKspls2DR_fit=coxDKspls2DR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",dataXplan=data.frame(X_train_micro),eta=.5))
+
+(cox_DKspls2DR_fit=coxDKspls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE,eta=.5))
+(cox_DKspls2DR_fit=coxDKspls2DR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE,eta=.5))
+(cox_DKspls2DR_fit=coxDKspls2DR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",allres=TRUE,dataXplan=data.frame(X_train_micro),eta=.5))
+
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_DKspls2DR_fit)
+
+
+
 cleanEx()
 nameEx("coxDKsplsDR")
 ### * coxDKsplsDR
@@ -139,37 +218,6 @@ nameEx("coxpls")
 
 flush(stderr()); flush(stdout())
 
-### Name: coxpls2
-### Title: Fitting a Cox-Model on PLSR components
-### Aliases: coxpls2 coxpls2.default coxpls2.formula
-### Keywords: models regression
-
-### ** Examples
-
-data(micro.censure)
-data(Xmicro.censure_compl_imp)
-
-X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
-X_train_micro_df <- data.frame(X_train_micro)
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-
-(cox_pls2_fit <- coxpls2(X_train_micro,Y_train_micro,C_train_micro,nt=7,typeVC="none"))
-(cox_pls2_fit2 <- coxpls2(~X_train_micro,Y_train_micro,C_train_micro,nt=7,typeVC="none"))
-(cox_pls2_fit3 <- coxpls2(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df))
-(cox_pls2_fit4 <- coxpls2(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE))
-(cox_pls2_fit5 <- coxpls2(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE,sparseStop=FALSE))
-                                                                                                         
-rm(X_train_micro,Y_train_micro,C_train_micro,cox_pls2_fit,cox_pls2_fit2,cox_pls2_fit3,cox_pls2_fit4,cox_pls2_fit5)
-
-
-
-cleanEx()
-nameEx("coxpls2")
-### * coxpls2
-
-flush(stderr()); flush(stdout())
-
 ### Name: coxpls
 ### Title: Fitting a Cox-Model on PLSR components
 ### Aliases: coxpls coxpls.default coxpls.formula
@@ -185,14 +233,135 @@ X_train_micro_df <- data.frame(X_train_micro)
 Y_train_micro <- micro.censure$survyear[1:80]
 C_train_micro <- micro.censure$DC[1:80]
 
-(cox_pls_fit=coxpls(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
-(cox_pls_fit=coxpls(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
-(cox_pls_fit=coxpls(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",dataXplan=X_train_micro_df))
+(cox_pls_fit=coxpls(X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
+(cox_pls_fit=coxpls(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
+(cox_pls_fit=coxpls(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df))
 
 rm(X_train_micro,Y_train_micro,C_train_micro,cox_pls_fit)
 
 
 
+cleanEx()
+nameEx("coxpls2")
+### * coxpls2
+
+flush(stderr()); flush(stdout())
+
+### Name: coxpls2
+### Title: Fitting a Cox-Model on PLSR components
+### Aliases: coxpls2 coxpls2.default coxpls2.formula
+### Keywords: models regression
+
+### ** Examples
+
+data(micro.censure)
+data(Xmicro.censure_compl_imp)
+
+X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
+X_train_micro_df <- data.frame(X_train_micro)
+Y_train_micro <- micro.censure$survyear[1:80]
+C_train_micro <- micro.censure$DC[1:80]
+
+(cox_pls_fit=coxpls2(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
+(cox_pls_fit=coxpls2(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="CV"))
+(cox_pls_fit=coxpls2(~.,Y_train_micro,C_train_micro,ncomp=6,validation="CV",dataXplan=X_train_micro_df))
+
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_pls_fit)
+
+
+
+cleanEx()
+nameEx("coxpls2DR")
+### * coxpls2DR
+
+flush(stderr()); flush(stdout())
+
+### Name: coxpls2DR
+### Title: Fitting a PLSR model on the (Deviance) Residuals
+### Aliases: coxpls2DR coxpls2DR.default coxpls2DR.formula
+### Keywords: models regression
+
+### ** Examples
+
+data(micro.censure)
+data(Xmicro.censure_compl_imp)
+
+X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
+X_train_micro_df <- data.frame(X_train_micro)
+Y_train_micro <- micro.censure$survyear[1:80]
+C_train_micro <- micro.censure$DC[1:80]
+
+(cox_pls2DR_fit=coxpls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="none"))
+(cox_pls2DR_fit2=coxpls2DR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="none"))
+(cox_pls2DR_fit3=coxpls2DR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="none",dataXplan=X_train_micro_df))
+
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_pls2DR_fit,cox_pls2DR_fit2,cox_pls2DR_fit3)
+
+
+
+cleanEx()
+nameEx("coxpls3")
+### * coxpls3
+
+flush(stderr()); flush(stdout())
+
+### Name: coxpls3
+### Title: Fitting a Cox-Model on PLSR components
+### Aliases: coxpls3 coxpls3.default coxpls3.formula
+### Keywords: models regression
+
+### ** Examples
+
+data(micro.censure)
+data(Xmicro.censure_compl_imp)
+
+X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
+X_train_micro_df <- data.frame(X_train_micro)
+Y_train_micro <- micro.censure$survyear[1:80]
+C_train_micro <- micro.censure$DC[1:80]
+
+(cox_pls3_fit <- coxpls3(X_train_micro,Y_train_micro,C_train_micro,nt=7,typeVC="none"))
+(cox_pls3_fit2 <- coxpls3(~X_train_micro,Y_train_micro,C_train_micro,nt=7,typeVC="none"))
+(cox_pls3_fit3 <- coxpls3(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df))
+(cox_pls3_fit4 <- coxpls3(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE))
+(cox_pls3_fit5 <- coxpls3(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE,sparseStop=FALSE))
+                                                                                                         
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_pls3_fit,cox_pls3_fit2,cox_pls3_fit3,cox_pls3_fit4,cox_pls3_fit5)
+
+
+
+cleanEx()
+nameEx("coxpls3DR")
+### * coxpls3DR
+
+flush(stderr()); flush(stdout())
+
+### Name: coxpls3DR
+### Title: Fitting a PLSR model on the (Deviance) Residuals
+### Aliases: coxpls3DR coxpls3DR.default coxpls3DR.formula
+### Keywords: models regression
+
+### ** Examples
+
+data(micro.censure)
+data(Xmicro.censure_compl_imp)
+
+X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
+X_train_micro_df <- data.frame(X_train_micro)
+Y_train_micro <- micro.censure$survyear[1:80]
+C_train_micro <- micro.censure$DC[1:80]
+
+(cox_pls3DR_fit <- coxpls3DR(X_train_micro,Y_train_micro,C_train_micro,nt=7))
+(cox_pls3DR_fit2 <- coxpls3DR(~X_train_micro,Y_train_micro,C_train_micro,nt=7))
+(cox_pls3DR_fit3 <- coxpls3DR(~.,Y_train_micro,C_train_micro,nt=7,dataXplan=X_train_micro_df))
+(cox_pls3DR_fit4 <- coxpls3DR(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE))
+(cox_pls3DR_fit5 <- coxpls3DR(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE,sparseStop=FALSE))
+
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_pls3DR_fit,cox_pls3DR_fit2,cox_pls3DR_fit3,cox_pls3DR_fit4,cox_pls3DR_fit5)
+
+
+
+
 cleanEx()
 nameEx("coxplsDR")
 ### * coxplsDR
@@ -214,23 +383,23 @@ X_train_micro_df <- data.frame(X_train_micro)
 Y_train_micro <- micro.censure$survyear[1:80]
 C_train_micro <- micro.censure$DC[1:80]
 
-(cox_plsDR_fit=coxplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="none"))
-(cox_plsDR_fit2=coxplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,validation="none"))
-(cox_plsDR_fit3=coxplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,validation="none",dataXplan=X_train_micro_df))
+(cox_plsDR_fit=coxplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
+(cox_plsDR_fit2=coxplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6))
+(cox_plsDR_fit3=coxplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df))
 
 rm(X_train_micro,Y_train_micro,C_train_micro,cox_plsDR_fit,cox_plsDR_fit2,cox_plsDR_fit3)
 
 
 
 cleanEx()
-nameEx("coxplsDR2")
-### * coxplsDR2
+nameEx("coxspls2DR")
+### * coxspls2DR
 
 flush(stderr()); flush(stdout())
 
-### Name: coxplsDR2
-### Title: Fitting a PLSR model on the (Deviance) Residuals
-### Aliases: coxplsDR2 coxplsDR2.default coxplsDR2.formula
+### Name: coxspls2DR
+### Title: Fitting a sPLSR model on the (Deviance) Residuals
+### Aliases: coxspls2DR coxspls2DR.default coxspls2DR.formula
 ### Keywords: models regression
 
 ### ** Examples
@@ -243,14 +412,11 @@ X_train_micro_df <- data.frame(X_train_micro)
 Y_train_micro <- micro.censure$survyear[1:80]
 C_train_micro <- micro.censure$DC[1:80]
 
-(cox_plsDR2_fit <- coxplsDR2(X_train_micro,Y_train_micro,C_train_micro,nt=7))
-(cox_plsDR2_fit2 <- coxplsDR2(~X_train_micro,Y_train_micro,C_train_micro,nt=7))
-(cox_plsDR2_fit3 <- coxplsDR2(~.,Y_train_micro,C_train_micro,nt=7,dataXplan=X_train_micro_df))
-(cox_plsDR2_fit4 <- coxplsDR2(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE))
-(cox_plsDR2_fit5 <- coxplsDR2(~.,Y_train_micro,C_train_micro,nt=7,typeVC="none",data=X_train_micro_df,sparse=TRUE,sparseStop=FALSE))
-
-rm(X_train_micro,Y_train_micro,C_train_micro,cox_plsDR2_fit,cox_plsDR2_fit2,cox_plsDR2_fit3,cox_plsDR2_fit4,cox_plsDR2_fit5)
-
+(cox_spls2DR2_fit=coxspls2DR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5))
+(cox_spls2DR2_fit=coxspls2DR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5,trace=TRUE))
+(cox_spls2DR2_fit=coxspls2DR(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df,eta=.5))
+                                                                                                         
+rm(X_train_micro,Y_train_micro,C_train_micro,cox_spls2DR_fit,cox_spls2DR_fit2,cox_spls2DR_fit3)
 
 
 
@@ -275,9 +441,9 @@ X_train_micro_df <- data.frame(X_train_micro)
 Y_train_micro <- micro.censure$survyear[1:80]
 C_train_micro <- micro.censure$DC[1:80]
 
-(cox_splsDR2_fit=coxsplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5))
-(cox_splsDR2_fit=coxsplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5,trace=TRUE))
-(cox_splsDR2_fit=coxsplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df,eta=.5))
+(cox_splsDR_fit=coxsplsDR(X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5))
+(cox_splsDR_fit2=coxsplsDR(~X_train_micro,Y_train_micro,C_train_micro,ncomp=6,eta=.5,trace=TRUE))
+(cox_splsDR_fit3=coxsplsDR(~.,Y_train_micro,C_train_micro,ncomp=6,dataXplan=X_train_micro_df,eta=.5))
                                                                                                          
 rm(X_train_micro,Y_train_micro,C_train_micro,cox_splsDR_fit,cox_splsDR_fit2,cox_splsDR_fit3)
 
@@ -296,23 +462,6 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-data(micro.censure)
-data(Xmicro.censure_compl_imp)
-
-X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
-X_train_micro_df <- data.frame(X_train_micro)
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-
-(cox_larsDR_fit <- larsDR_coxph(X_train_micro,Y_train_micro,C_train_micro,max.steps=6,use.Gram=FALSE,scaleX=TRUE))
-(cox_larsDR_fit <- larsDR_coxph(~X_train_micro,Y_train_micro,C_train_micro,max.steps=6,use.Gram=FALSE,scaleX=TRUE))
-(cox_larsDR_fit <- larsDR_coxph(~.,Y_train_micro,C_train_micro,max.steps=6,use.Gram=FALSE,scaleX=TRUE,dataXplan=X_train_micro_df))
-
-larsDR_coxph(~X_train_micro,Y_train_micro,C_train_micro,max.steps=6,use.Gram=FALSE)
-larsDR_coxph(~X_train_micro,Y_train_micro,C_train_micro,max.steps=6,use.Gram=FALSE,scaleX=FALSE)
-larsDR_coxph(~X_train_micro,Y_train_micro,C_train_micro,max.steps=6,use.Gram=FALSE,scaleX=TRUE,allres=TRUE)
-
-rm(X_train_micro,Y_train_micro,C_train_micro,cox_larsDR_fit)
 
 
 
@@ -329,28 +478,6 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-data(micro.censure)
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-Y_test_micro <- micro.censure$survyear[81:117]
-C_test_micro <- micro.censure$DC[81:117]
-rm(Y_train_micro,C_train_micro,Y_test_micro,C_test_micro)
-
-
-
-cleanEx()
-nameEx("plsRcox-package")
-### * plsRcox-package
-
-flush(stderr()); flush(stdout())
-
-### Name: plsRglm-package
-### Title: Partial least squares Regression for generalized linear models
-### Aliases: plsRglm-package
-### Keywords: package
-
-### ** Examples
-
 
 
 
@@ -368,21 +495,6 @@ flush(stderr()); flush(stdout())
 ### ** Examples
 
 
-data(micro.censure)
-data(Xmicro.censure_compl_imp)
-
-X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
-X_train_micro_df <- data.frame(X_train_micro)
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-
-plsRcox(X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5)$InfCrit
-plsRcox(~X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5)$InfCrit
-
-plsRcox(Xplan=X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5,sparse=TRUE,alpha.pvals.expli=.15)$InfCrit
-plsRcox(Xplan=~X_train_micro,time=Y_train_micro,event=C_train_micro,nt=5,sparse=TRUE,alpha.pvals.expli=.15)$InfCrit
-
-
 
 
 cleanEx()
@@ -426,15 +538,6 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-data(micro.censure)
-data(Xmicro.censure_compl_imp)
-
-X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-
-modpls <- plsRcox(X_train_micro,time=Y_train_micro,event=C_train_micro,nt=3)
-print(modpls)
 
 
 
@@ -451,15 +554,6 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-data(micro.censure)
-data(Xmicro.censure_compl_imp)
-
-X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-
-modpls <- plsRcox(X_train_micro,time=Y_train_micro,event=C_train_micro,nt=3)
-print(summary(modpls))
 
 
 
@@ -476,21 +570,12 @@ flush(stderr()); flush(stdout())
 
 ### ** Examples
 
-data(micro.censure)
-data(Xmicro.censure_compl_imp)
-
-X_train_micro <- apply((as.matrix(Xmicro.censure_compl_imp)),FUN="as.numeric",MARGIN=2)[1:80,]
-Y_train_micro <- micro.censure$survyear[1:80]
-C_train_micro <- micro.censure$DC[1:80]
-
-modpls <- plsRcox(X_train_micro,time=Y_train_micro,event=C_train_micro,nt=3)
-summary(modpls)
 
 
 
 ### * <FOOTER>
 ###
-cat("Time elapsed: ", proc.time() - get("ptime", pos = 'CheckExEnv'),"\n")
+base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
 grDevices::dev.off()
 ###
 ### Local variables: ***
